[flashrom] [Patch] Board enable for Asus P4B266LM.

Luc Verhaegen libv at skynet.be
Tue Oct 6 16:57:41 CEST 2009


Allan, please try this patch.

If this works, please reply with:
Acked-by: Allan Bjorklund <abjork at speakeasy.net>

Thanks,

Luc Verhaegen.
-------------- next part --------------
Board enable for Asus P4B266LM.

Found in the Sony Vaio PCV-RX650.

Uses the same board enable (but different ICH) as the Asus P4P800-E.

Signed-off-by: Luc Verhaegen <libv at skynet.be>
Index: board_enable.c
===================================================================
--- board_enable.c	(revision 746)
+++ board_enable.c	(working copy)
@@ -989,7 +989,9 @@
 }
 
 /**
  * Suited for Asus P4P800-E Deluxe: Intel Intel 865PE + ICH5R.
  */
 static int board_asus_p4p800(const char *name)
 {
@@ -998,8 +1000,10 @@
 	uint8_t tmp;
 
 	dev = pci_dev_find(0x8086, 0x24D0);	/* Intel ICH5R ISA Bridge */
+	if (!dev)
+	    dev = pci_dev_find(0x8086, 0x2440);	/* Intel ICH2 ISA Bridge */
 	if (!dev) {
-		fprintf(stderr, "\nERROR: Intel ICH5R ISA Bridge not found.\n");
+		fprintf(stderr, "\nERROR: Intel ISA Bridge not found.\n");
 		return -1;
 	}
 
@@ -1048,6 +1052,7 @@
 	{0x1106, 0x3189, 0x1043, 0x807F,  0x1106, 0x3177, 0x1043, 0x808C, NULL,         NULL,          "ASUS",        "A7V8X",              board_asus_a7v8x},
 	{0x1106, 0x3177, 0x1043, 0x80A1,  0x1106, 0x3205, 0x1043, 0x8118, NULL,         NULL,          "ASUS",        "A7V8X-MX SE",        board_asus_a7v8x_mx},
 	{0x8086, 0x1a30, 0x1043, 0x8070,  0x8086, 0x244b, 0x1043, 0x8028, NULL,         NULL,          "ASUS",        "P4B266",             ich2_gpio22_raise},
+	{0x8086, 0x1A30, 0x1043, 0x8025,  0x8086, 0x244B, 0x104D, 0x80F0, NULL,         NULL,          "ASUS",        "P4B266-LM",          board_asus_p4p800},
 	{0x8086, 0x2570, 0x1043, 0x80F2,  0x105A, 0x3373, 0x1043, 0x80F5, NULL,         NULL,          "ASUS",        "P4P800-E Deluxe",    board_asus_p4p800},
 	{0x10B9, 0x1541,      0,      0,  0x10B9, 0x1533,      0,      0, "asus",       "p5a",         "ASUS",        "P5A",                board_asus_p5a},
 	{0x10DE, 0x0030, 0x1043, 0x818a,  0x8086, 0x100E, 0x1043, 0x80EE, NULL,         NULL,          "ASUS",        "P5ND2-SLI Deluxe",   board_asus_p5nd2_sli},
@@ -989,7 +989,9 @@
 
 /**
- * Suited for Asus P4P800-E Deluxe: Intel Intel 865PE + ICH5R.
+ * Suited for:
+ * Asus P4P800-E Deluxe: Intel socket478 + 865PE + ICH5R.
+ * Asus P4B266LM (Sony Vaio PCV-RX650): Intel socket478 + 845D + ICH2.
  */
 static int board_asus_p4p800(const char *name)


More information about the flashrom mailing list